@@ -13,8 +13,7 @@
 # | KIND, either express or implied. See the License for the specific        |
 # | language governing permissions and limitations under the License.        |
 # +--------------------------------------------------------------------------+
-# | Authors: Ambrish Bhargava, Tarun Pasrija                                 |
-# | Version: 0.1.4                                                           |
+# | Authors: Ambrish Bhargava, Tarun Pasrija, Rahul Priyadarshi              |
 # +--------------------------------------------------------------------------+
 
 """
@@ -27,6 +26,7 @@ try:
     import ibm_db_dbi as Database
 except ImportError, e:
     raise ImportError("ibm_db module not found. Install ibm_db module from http://code.google.com/p/ibm-db/.")
+import sys
 
 # Importing class from base module of django.db.backends
 from django.db.backends import BaseDatabaseFeatures
@@ -42,11 +42,13 @@ from ibm_db_django.operations import DatabaseOperations
 # For validation, importing types class
 import types
 from django import VERSION as djangoVersion
+if (djangoVersion[0:2] > (1, 1)):
+    from django.db import utils
 
 DatabaseError = Database.DatabaseError
 IntegrityError = Database.IntegrityError
 
-class DatabaseFeatures ( BaseDatabaseFeatures ):    
+class DatabaseFeatures(BaseDatabaseFeatures):    
     can_use_chunked_reads               = False
     
     #Save point is supported by DB2.
@@ -56,12 +58,12 @@ class DatabaseFeatures ( BaseDatabaseFeatures ):
     #django.db.backends.db2.query.query_class.DB2QueryClass
     uses_custom_query_class             = True
 
-class DatabaseValidation ( BaseDatabaseValidation ):    
+class DatabaseValidation(BaseDatabaseValidation):    
     #Need to do validation for DB2 and ibm_db version
-    def validate_field ( self, errors, opts, f ):
+    def validate_field(self, errors, opts, f):
         pass
 
-class DatabaseWrapper (BaseDatabaseWrapper):
+class DatabaseWrapper(BaseDatabaseWrapper):
     
     """
     This is the base class for DB2 backend support for Django. The under lying 
@@ -90,32 +92,33 @@ class DatabaseWrapper (BaseDatabaseWrapper):
 
         self.features = DatabaseFeatures()
         self.ops = DatabaseOperations()
-        from django import VERSION as djangoVersion
-        if(djangoVersion[0] == 1 and djangoVersion[1] == 0):
+        if(djangoVersion[0:2] <= (1, 0)):
             self.client = DatabaseClient()
-        elif(djangoVersion[0] == 1 and djangoVersion[1] == 1):
+        else:
             self.client = DatabaseClient(self)
         self.creation = DatabaseCreation(self)
         self.introspection = DatabaseIntrospection(self)
-        self.validation = DatabaseValidation()
+        if(djangoVersion[0:2] <= (1, 1)):
+            self.validation = DatabaseValidation()
+        else:
+            self.validation = DatabaseValidation(self)
 
     # Method to check if connection is live or not.
     def __is_connection(self):
         return self.connection is not None
     
     # Over-riding _cursor method to return DB2 cursor.
-    def _cursor (self, settings=None):
-        if not self.__is_connection():            
-            kwargs 			 = { }
-            
-            if(djangoVersion[0] == 1 and djangoVersion[1] == 0):
+    def _cursor(self, settings=None):
+        if not self.__is_connection():
+            kwargs = { }
+            if (djangoVersion[0:2] <= (1, 0)):
                 database_name = settings.DATABASE_NAME
                 database_user = settings.DATABASE_USER
                 database_pass = settings.DATABASE_PASSWORD
                 database_host = settings.DATABASE_HOST
                 database_port = settings.DATABASE_PORT
                 database_options = settings.DATABASE_OPTIONS
-            elif (djangoVersion[0] == 1 and djangoVersion[1] == 1):
+            elif (djangoVersion[0:2] <= (1, 1)):
                 settings_dict = self.settings_dict
                 database_name = settings_dict['DATABASE_NAME']
                 database_user = settings_dict['DATABASE_USER']
@@ -123,28 +126,36 @@ class DatabaseWrapper (BaseDatabaseWrapper):
                 database_host = settings_dict['DATABASE_HOST']
                 database_port = settings_dict['DATABASE_PORT']
                 database_options = settings_dict['DATABASE_OPTIONS']
-            
+            else:
+                settings_dict = self.settings_dict
+                database_name = settings_dict['NAME']
+                database_user = settings_dict['USER']
+                database_pass = settings_dict['PASSWORD']
+                database_host = settings_dict['HOST']
+                database_port = settings_dict['PORT']
+                database_options = settings_dict['OPTIONS']
+                
             if database_name =='':
                 from django.core.exceptions import ImproperlyConfigured
                 raise ImproperlyConfigured("Please specify the database Name to connect to")
             
-            if(isinstance(database_name, types.StringType) or
+            if (isinstance(database_name, types.StringType) or
                isinstance(database_name, types.UnicodeType)):
                 kwargs['database'] = database_name
                 
-            if(isinstance(database_user, types.StringType) or 
+            if (isinstance(database_user, types.StringType) or 
                isinstance(database_user, types.UnicodeType)):
                 kwargs['user'] = database_user
             
-            if(isinstance(database_pass, types.StringType) or
+            if (isinstance(database_pass, types.StringType) or
                isinstance(database_pass, types.UnicodeType)):
                 kwargs['password'] = database_pass
             
-            if(isinstance(database_host, types.StringType) or
+            if (isinstance(database_host, types.StringType) or
                isinstance(database_host, types.UnicodeType)):
                 kwargs['host'] = database_host
                 
-            if((isinstance(database_port, types.StringType) or
+            if ((isinstance(database_port, types.StringType) or
                 isinstance(database_port, types.UnicodeType)) and 
                 (isinstance(database_host, types.StringType) or
                 isinstance(database_host, types.UnicodeType))):
@@ -160,15 +171,15 @@ class DatabaseWrapper (BaseDatabaseWrapper):
             conn_options = {Database.SQL_ATTR_AUTOCOMMIT : Database.SQL_AUTOCOMMIT_OFF}
             kwargs['conn_options'] = conn_options
             kwargs.update(database_options)
-            self.connection = Database.connect (**kwargs)
+            self.connection = Database.pconnect(**kwargs)
         
         return DB2CursorWrapper(self.connection)
     
     
             
     def get_server_version(self):
-	if not(self.__is_connection()):
-		self.cursor()
+        if not (self.__is_connection()):
+            self.cursor()
         return tuple(int(version) for version in self.connection.server_info()[1].split("."))
     
 class DB2CursorWrapper(Database.Cursor):
@@ -179,14 +190,31 @@ class DB2CursorWrapper(Database.Cursor):
     hence this conversion is required. 
     """
     
-    def __init__(self, connection):
+    def __init__(self, connection): 
         super(DB2CursorWrapper, self).__init__(connection.conn_handler, connection)
     
+    def __iter__(self):
+        return self
+    
+    def next(self):
+        row = self.fetchone()
+        if row == None:
+            raise StopIteration
+        return row
+        
     # Over-riding this method to modify SQLs which contains format parameter to qmark. 
-    def execute(self, operation, parameters = ()):
+    def execute(self, operation, parameters=()):
         try:
             operation = operation % (tuple("?" * len(parameters)))
-            return super(DB2CursorWrapper, self).execute(operation, parameters)
+            if (djangoVersion[0:2] <= (1, 1)):
+                return super(DB2CursorWrapper, self).execute(operation, parameters)
+            else:
+                try:
+                    return super(DB2CursorWrapper, self).execute(operation, parameters)
+                except IntegrityError, e:
+                    raise utils.IntegrityError, utils.IntegrityError(*tuple(e)), sys.exc_info()[2]
+                except DatabaseError, e:
+                    raise utils.DatabaseError, utils.DatabaseError(*tuple(e)), sys.exc_info()[2]   
         except (TypeError):
             return None
     
@@ -194,6 +222,14 @@ class DB2CursorWrapper(Database.Cursor):
     def executemany(self, operation, seq_parameters):
         try:
             operation = operation % (tuple("?" * len(seq_parameters[0])))
-            return super(DB2CursorWrapper, self).executemany(operation, seq_parameters)
+            if (djangoVersion[0:2] <= (1, 1)):
+                return super(DB2CursorWrapper, self).executemany(operation, seq_parameters)
+            else:
+                try:
+                    return super(DB2CursorWrapper, self).executemany(operation, seq_parameters)
+                except IntegrityError, e:
+                    raise utils.IntegrityError, utils.IntegrityError(*tuple(e)), sys.exc_info()[2]
+                except DatabaseError, e:
+                    raise utils.DatabaseError, utils.DatabaseError(*tuple(e)), sys.exc_info()[2] 
         except (IndexError, TypeError):
             return None
